@@ -19,6 +19,7 @@
 """
  IMPORTS
 """
+import signal
 import sys
 import ConfigParser
 
@@ -34,7 +35,7 @@ import playerfactory as PlayerFactory
 import mediasong as MediaSong
 
 # The current version of Kap
-_VERSION = "0.4.0"
+_VERSION = "0.5.0"
 
 
 class Kap(wx.Frame):
@@ -130,6 +131,7 @@ class Kap(wx.Frame):
         self.__bindEvents()
         self.__doLayout()
         self.__trackTimer.Start(self.__trackRefreshRate)
+        signal.signal(signal.SIGINT, self.__signalExit)
 
     def __readSettings(self):
         """ Read the settings and use them.
@@ -641,6 +643,10 @@ class Kap(wx.Frame):
         if self.__playContinuous:
             self.__handleStartSong()
 
+    def __signalExit(self, signalNumber, frame):
+        """ Catches exit signal and exits Kap. """
+        self.__handleExit()
+
     def __onExit(self, event):
         """ Handles the exiting of the programme.
 
@@ -648,6 +654,10 @@ class Kap(wx.Frame):
            ensures the player is not left in an unknown state.
          wx.Event event: is the event object (Not Used)
         """
+        self.__handleExit()
+
+    def __handleExit(self):
+        """ Handles all the threads and saves the databases before exiting. """
         if self.__playerFactory.player.isRunning():
             self.__playerFactory.player.quitRunning()
         self.__writeSettings()
