@@ -23,6 +23,8 @@ from mediasong import MediaSong
 
 import wx
 
+import mediaparser as parser
+
 
 class SearchWindow(wx.Panel):
     """ Interface to search for a song in the media library. """
@@ -131,7 +133,11 @@ class SearchWindow(wx.Panel):
         # Search Navigation Events
         wx.EVT_BUTTON(self, self.__ID_PREVIOUS, self.__onPreviousSearch)
         wx.EVT_BUTTON(self, self.__ID_NEXT, self.__onNextSearch)
-        wx.EVT_SPINCTRL(self, self.__ID_PAGES, self.__OnPageChanged)
+        wx.EVT_SPINCTRL(self, self.__ID_PAGES, self.__onPageChanged)
+
+        # File Informaiton Events
+        wx.EVT_LIST_ITEM_RIGHT_CLICK(self, self.ID_SEARCH_RESULTS, \
+            self.__onFileInformaiton)
 
     def __doLayout(self):
         """ Creates a visually pleasing look for the controls.
@@ -211,7 +217,7 @@ class SearchWindow(wx.Panel):
                 self.__displayedResultsStartIndex])
             current = next
 
-    def __getNextSelectedSong(self, current):
+    def __getNextSelectedSong(self, current=-1):
         """ Get the next selected song in the results display.
 
          int current: is the current index.
@@ -331,7 +337,7 @@ class SearchWindow(wx.Panel):
             self.__spnCtrlPage.SetValue(self.__displayedResultsStartIndex / \
                 self.__MAXIMUM_DISPLAYED_RESULTS + 1)
 
-    def __OnPageChanged(self, event):
+    def __onPageChanged(self, event):
         """ Hangles the changes in pages from the user  """
         currentPage = self.__displayedResultsStartIndex / \
                 self.__MAXIMUM_DISPLAYED_RESULTS + 1
@@ -341,4 +347,21 @@ class SearchWindow(wx.Panel):
         elif currentPage < newPage:
             self.__onNextSearch(event)
         else:
-            return
\ No newline at end of file
+            return
+
+    def __onFileInformaiton(self, event):
+        """ Handles the display of file informaiton """
+        song = self.__searchResults[self.__getNextSelectedSong() + \
+                self.__displayedResultsStartIndex]
+        songInfo = parser.MediaParser(song)
+        if songInfo.hasInformation():
+            knownInformation = songInfo.information()
+            info = ""
+            for key in knownInformation.keys():
+                info += "  %s: %s\n" % (key, knownInformation[key])
+            dlg = wx.MessageDialog(self, info,"Media Informaiton", \
+                wx.ICON_INFORMATION | wx.OK)
+        else:
+            dlg = wx.MessageDialog(self, "Unable to locate song %s." % song, \
+                "Media Informaiton Error", wx.ICON_INFORMATION | wx.OK)
+        dlg.ShowModal()
